# -*- coding: utf-8 -*-
# Generated by Django 1.9.12 on 2017-07-10 15:56
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oscar_webpay', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='webpaytransaction',
            name='error_auth_code',
            field=models.CharField(choices=[(b'TSY', 'Successful transaction'), (b'TSN', 'Failed transaction'), (b'TO', 'Time limit exceeded'), (b'ABO', 'Transaction aborted by card holder'), (b'U3', 'Authentication internal error')], max_length=3, null=True, verbose_name='Error code'),
        ),
    ]
